// (C) 2017-2020 by folkert van heusden, released under AGPL v3.0
#include <stddef.h>
#include <stdlib.h>
#include <string.h>

#include "resize_crop.h"
#include "log.h"
#include "utils.h"

resize_crop::resize_crop(const bool resize_crop_center) : resize_crop_center(resize_crop_center)
{
	log(LL_INFO, "Generic resize_crop instantiated");
}

resize_crop::~resize_crop()
{
}

void resize_crop::do_resize(const int win, const int hin, const uint8_t *const in, const int wout, const int hout, uint8_t **out)
{
	size_t out_size = wout * hout * 3;

	*out = (uint8_t *)allocate_aligned(out_size);

	memset(*out, 0x00, out_size);

	int xoffset = resize_crop_center && wout > win ? (wout - win) / 2 : 0;
	int yoffset = resize_crop_center && hout > hin ? (hout - hin) / 2 : 0;

	int new_width = std::min(win, wout);

	for(int y=0; y<std::min(hin, hout); y++)
		memcpy(&(*out)[(y + yoffset) * wout * 3 + xoffset * 3], &in[y * win * 3], new_width * 3);
}
